@@ -1,6 +1,6 @@
 import numpy as np
 import xgboost as xgb
-from ..objectives.squareloss import squareloss_gradient_hessian
+from ..objectives.squareloss import squareloss_gradient_hessian, multi_squareloss_gradient_hessian
 from ..objectives.categoricallogloss import categoricallogloss_gradient_hessian
 from ..objectives.binarylogloss import binarylogloss_gradient_hessian
 from ..evals.classification import error, logloss, merror, mlogloss
@@ -33,7 +33,16 @@ class eval:
 def train(param,dtrain,num_boost_round=10,evals=(),obj=None,
           feval=None,maximize=False,early_stopping_rounds=None,evals_result=None,
           verbose_eval=True,xgb_model=None,callbacks=None):
-    
+    """train -- Trains a wideboost model using the XGBoost backend.
+
+    Args:
+        param (list): Named parameter list. Uses XGBoost conventions. Requires 
+            two parameters in addition to the usual XGBoost parameters,
+            'btype' and 'extra_dims'. 
+
+    Returns:
+        wxgb: A wxgb object containing the XGBoost object with objective and evaluation objects.
+    """
     params = param.copy()
     if not isinstance(obj,xgb_objective):
         assert params['extra_dims'] >= 0
@@ -97,13 +106,16 @@ def get_eval_metric(params,obj):
         'squarederror':eval(squarederror,obj,'squarederror'),
         'rmse':eval(rmse,obj,'rmse')
     }
-    print("Taking first argument of eval_metric. Multiple evals not supported using xgboost backend.")
-    return output_dict[params['eval_metric'][0]]
+    if isinstance(params['eval_metric'], list) or isinstance(params['eval_metric'], tuple):
+        print("Taking first argument of eval_metric. Multiple evals not supported using xgboost backend.")
+        return output_dict[params['eval_metric'][0]]
+    return output_dict[params['eval_metric']]
 
 def get_objective(params):
     output_dict = {
         'binary:logistic':xgb_objective(params['btype'],params['extra_dims'],params['num_class'],binarylogloss_gradient_hessian),
         'reg:squarederror':xgb_objective(params['btype'],params['extra_dims'],params['num_class'],squareloss_gradient_hessian),
+        'multi:squarederror':xgb_objective(params['btype'],params['extra_dims'],params['num_class'],multi_squareloss_gradient_hessian),
         'multi:softmax':xgb_objective(params['btype'],params['extra_dims'],params['num_class'],categoricallogloss_gradient_hessian)
         }
     return output_dict[params['objective']]
